@@ -1,9 +1,9 @@
 /*
  * gEDA - GNU Electronic Design Automation
  * drill.c
- * Copyright (C) 2000-2003 Andreas Andersson
+ * Copyright (C) 2000-2006 Andreas Andersson
  *
- * $Id: drill.c,v 1.34 2004/05/19 20:01:17 spetm Exp $
+ * $Id: drill.c,v 1.34.8.3 2006/07/25 21:47:59 spetm Exp $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -209,6 +209,8 @@ parse_drillfile(gerb_file_t *fd)
 	    drill_parse_coordinate(fd, read, 1.0 / x_scale, state);
 
 	    curr_net->next = (gerb_net_t *)malloc(sizeof(gerb_net_t));
+	    if (curr_net->next == NULL)
+		GERB_FATAL_ERROR("malloc curr_net->next failed\n");
 	    curr_net = curr_net->next;
 	    memset((void *)curr_net, 0, sizeof(gerb_net_t));
 
@@ -217,8 +219,8 @@ parse_drillfile(gerb_file_t *fd)
 	    /* KLUDGE. This function isn't allowed to return anything
 	       but inches */
 	    if(state->unit == MM) {
-		(double)curr_net->start_x /= 25.4;
-		(double)curr_net->start_y /= 25.4;
+		curr_net->start_x /= 25.4;
+		curr_net->start_y /= 25.4;
 		/* KLUDGE. All images, regardless of input format,
 		   are returned in INCH format */
 		curr_net->unit = INCH;
@@ -231,6 +233,13 @@ parse_drillfile(gerb_file_t *fd)
 
 	    /* Find min and max of image.
 	       Mustn't forget (again) to add the hole radius */
+
+ 
+	    /* Check if aperture is set. Ignore the below instead of
+	       causing SEGV... */
+	    if(image->aperture[state->current_tool] == NULL)
+		break;
+
 	    image->info->min_x =
 		min(image->info->min_x,
 		    (curr_net->start_x -
@@ -270,6 +279,8 @@ parse_drillfile(gerb_file_t *fd)
 
     GERB_COMPILE_ERROR("Warning: File is missing drill End-Of-File\n");
 
+    free(state);
+
     return image;
 } /* parse_drillfile */
 
@@ -617,7 +628,7 @@ drill_parse_M_code(gerb_file_t *fd, gerb_image_t *image)
     if ((read[0] == EOF) || (read[1] == EOF))
 	GERB_COMPILE_WARNING("Unexpected EOF found.\n");
 
-    op[0] = read[0], op[1] = read[1], op[3] = 0;
+    op[0] = read[0], op[1] = read[1], op[2] = 0;
  
     if (strncmp(op, "00", 2) == 0) {
 	return DRILL_M_END;
@@ -663,7 +674,7 @@ drill_parse_G_code(gerb_file_t *fd, gerb_image_t *image)
     if ((read[0] == EOF) || (read[1] == EOF))
 	GERB_COMPILE_ERROR("Unexpected EOF found.\n");
 
-    op[0] = read[0], op[1] = read[1], op[3] = 0;
+    op[0] = read[0], op[1] = read[1], op[2] = 0;
 
     if (strncmp(op, "00", 2) == 0) {
 	return DRILL_G_ROUT;
