@@ -2,9 +2,9 @@
  * gEDA - GNU Electronic Design Automation
  * This file is a part of gerbv.
  *
- *   Copyright (C) 2000-2002 Stefan Petersen (spe@stacken.kth.se)
+ *   Copyright (C) 2000-2006 Stefan Petersen (spe@stacken.kth.se)
  *
- * $Id: gerb_file.c,v 1.14.6.1 2005/02/08 09:09:36 motyl Exp $
+ * $Id: gerb_file.c,v 1.14.6.8 2006/07/25 21:47:59 spetm Exp $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,6 +37,7 @@
 #include <sys/mman.h>
 #include <errno.h>
 
+#include "gerb_error.h"
 #include "gerb_file.h"
 
 gerb_file_t *
@@ -52,17 +53,26 @@ gerb_fopen(char *filename)
 
     fd->fd = fopen(filename, "r");
     if (fd->fd == NULL) {
+	free(fd);
 	return NULL;
     }
 
     fd->ptr = 0;
     fd->fileno = fileno(fd->fd);
-    fstat(fd->fileno, &statinfo);
+    if (fstat(fd->fileno, &statinfo) < 0) {
+	fclose(fd->fd);
+	free(fd);
+	return NULL;
+    }
     if (!S_ISREG(statinfo.st_mode)) {
+	fclose(fd->fd);
+	free(fd);
 	errno = EISDIR;
 	return NULL;
     }
     if ((int)statinfo.st_size == 0) {
+	fclose(fd->fd);
+	free(fd);
 	errno = EIO; /* More compatible with the world outside Linux */
 	return NULL;
     }
@@ -83,7 +93,7 @@ int
 gerb_fgetc(gerb_file_t *fd)
 {
 
-    if (fd->ptr > fd->datalen || fd->datalen == 0)
+    if (fd->ptr >= fd->datalen)
 	return EOF;
 
     return (int) fd->data[fd->ptr++];
@@ -96,7 +106,12 @@ gerb_fgetint(gerb_file_t *fd, int *len)
     long int result;
     char *end;
     
+    errno = 0;
     result = strtol(fd->data + fd->ptr, &end, 10);
+    if (errno) {
+	GERB_COMPILE_ERROR("Failed to read integer");
+	return 0;
+    }
 
     if (len) {
 	*len = end - (fd->data + fd->ptr);
@@ -104,6 +119,9 @@ gerb_fgetint(gerb_file_t *fd, int *len)
 
     fd->ptr = end - fd->data;
 
+    if (len && (result < 0))
+	*len -= 1;
+
     return (int)result;
 } /* gerb_fgetint */
 
@@ -114,7 +132,13 @@ gerb_fgetdouble(gerb_file_t *fd)
     double result;
     char *end;
     
+    errno = 0;
     result = strtod(fd->data + fd->ptr, &end);
+    if (errno) {
+	GERB_COMPILE_ERROR("Failed to read double");
+	return 0.0;
+    }
+
     fd->ptr = end - fd->data;
 
     return result;
@@ -124,11 +148,19 @@ gerb_fgetdouble(gerb_file_t *fd)
 char *
 gerb_fgetstring(gerb_file_t *fd, char term)
 {
-    char *strend;
+    char *strend = NULL;
     char *newstr;
+    char *i, *iend;
     int len;
     
-    strend = strchr(fd->data + fd->ptr, term);
+    iend = fd->data + fd->datalen;
+    for (i = fd->data + fd->ptr; i < iend; i++) {
+	if (*i == term) {
+	    strend = i;
+	    break;
+	}
+    }
+
     if (strend == NULL)
 	return NULL;
 
@@ -158,10 +190,14 @@ gerb_ungetc(gerb_file_t *fd)
 void
 gerb_fclose(gerb_file_t *fd)
 {
-    munmap(fd->data, fd->datalen);
-    fclose(fd->fd);
-    free(fd);
-    
+    if (fd) {
+	if (munmap(fd->data, fd->datalen) < 0)
+	    GERB_FATAL_ERROR("gerb_fclose:munmap:%s\n", strerror(errno));
+	if (fclose(fd->fd) == EOF)
+	    GERB_FATAL_ERROR("gerb_fclose:fclose:%s\n", strerror(errno));
+	free(fd);
+    }
+
     return;
 } /* gerb_fclose */
 
@@ -188,13 +224,17 @@ gerb_find_file(char *filename, char **paths)
 		len = strlen(paths[i]) - 1;
 	    else
 		len = tmp - paths[i] - 1;
-	    env_name = (char *)malloc(len+1);
+	    env_name = (char *)malloc(len + 1);
+	    if (env_name == NULL)
+		return NULL;
 	    strncpy(env_name, (char *)(paths[i] + 1), len);
 	    env_name[len] = '\0';
 
 	    env_value = getenv(env_name);
 	    if (env_value == NULL) break;
 	    curr_path = (char *)malloc(strlen(env_value) + strlen(&paths[i][len + 1]) + 1);
+	    if (curr_path == NULL)
+		return NULL;
 	    strcpy(curr_path, env_value);
 	    strcat(curr_path, &paths[i][len + 1]);
 	    free(env_name);
@@ -206,6 +246,8 @@ gerb_find_file(char *filename, char **paths)
 	 * Build complete path (inc. filename) and check if file exists.
 	 */
 	complete_path = (char *)malloc(strlen(curr_path) + strlen(filename) + 2);
+	if (complete_path == NULL)
+	    return NULL;
 	strcpy(complete_path, curr_path);
 	complete_path[strlen(curr_path)] = '/';
 	complete_path[strlen(curr_path) + 1] = '\0';
@@ -218,5 +260,8 @@ gerb_find_file(char *filename, char **paths)
 	complete_path = NULL;
     }
 
+    if (complete_path == NULL)
+	errno = ENOENT;
+
     return complete_path;
 } /* gerb_find_file */
