@@ -4,7 +4,7 @@
  *
  *   Copyright (C) 2000-2001 Stefan Petersen (spe@stacken.kth.se)
  *
- * $Id: gerb_image.h,v 1.18 2004/06/24 19:56:15 spetm Exp $
+ * $Id: gerb_image.h,v 1.18.8.1 2006/07/23 21:28:11 spetm Exp $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -103,6 +103,8 @@ typedef struct gerb_image_info {
     double max_y;
     double offset_a;
     double offset_b;
+    double offset_a_in;
+    double offset_b_in;
     enum encoding_t encoding;
     double scale_factor_A;  /* SF parameters */
     double scale_factor_B;
