@@ -2,9 +2,9 @@
  * gEDA - GNU Electronic Design Automation
  * This files is a part of gerbv.
  *
- *   Copyright (C) 2000-2001 Stefan Petersen (spe@stacken.kth.se)
+ *   Copyright (C) 2000-2002 Stefan Petersen (spe@stacken.kth.se)
  *
- * $Id: gerber.h,v 1.13 2001/12/03 22:48:26 spetm Exp $
+ * $Id: gerber.h,v 1.17 2002/10/18 21:04:53 spetm Exp $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,26 +32,11 @@ extern "C" {
 #include "gerb_image.h"
 #include "gerb_file.h"
 
-
-#define EAGLECAD_KLUDGE 
-
 /*
  * parse gerber file pointed to by fd
  */
 gerb_image_t *parse_gerb(gerb_file_t *fd);
 
-/*
- * Check that the parsed gerber image is complete.
- * Returned errorcodes are:
- * 0: No problems
- * 1: Missing netlist
- * 2: Missing format
- * 4: Missing apertures
- * 8: Missing info
- * It could be any of above or'ed together
- */
-int check_gerb(gerb_image_t *image);
-
 
 #ifdef __cplusplus
 }
