@@ -4,7 +4,7 @@
  *
  *   Copyright (C) 2000-2003 Stefan Petersen (spe@stacken.kth.se)
  *
- * $Id: gerbv.c,v 1.142.6.3 2005/02/08 09:09:36 motyl Exp $
+ * $Id: gerbv.c,v 1.142.6.7 2006/07/28 10:33:13 spetm Exp $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -43,15 +43,12 @@
 #include <gtk/gtk.h>
 #include <gdk/gdk.h>
 #include <gdk/gdkkeysyms.h>
+#include <pango/pango.h>
 
 #ifdef HAVE_GETOPT_H
 #include <getopt.h>
 #endif
 
-#ifdef USE_GTK2
-#include <pango/pango.h>
-#endif
-
 #include "gerber.h"
 #include "drill.h"
 #include "gerb_error.h"
@@ -224,11 +221,7 @@ create_menubar(GtkWidget *window, GtkWidget **menubar)
     gtk_item_factory_create_items(item_factory, nmenu_items, menu_items, NULL);
     
     /* Attach the new accelerator group to the window */
-#ifdef USE_GTK2
     gtk_window_add_accel_group (GTK_WINDOW(window), accel_group);
-#else
-    gtk_accel_group_attach(accel_group, GTK_OBJECT(window));
-#endif
     
     if(menubar) {
 	GtkWidget *menuEntry;
@@ -596,6 +589,8 @@ cb_ok_load_file(GtkWidget *widget, GtkFileSelection *fs)
 	if (screen.path)
 	    free(screen.path);
 	screen.path = (char *)malloc(strlen(filename) + 2);
+	if (screen.path == NULL)
+	    GERB_FATAL_ERROR("malloc screen.path failed\n");
 	strcpy(screen.path, filename);
 	screen.path = strncat(screen.path, "/", 1);
 	
@@ -693,6 +688,8 @@ cb_ok_export_png(GtkWidget *widget, GtkFileSelection *fs)
     if (screen.path)
 	free(screen.path);
     screen.path = (char *)malloc(strlen(filename) + 2);
+    if (screen.path == NULL)
+	GERB_FATAL_ERROR("malloc screen.path failed\n");
     strcpy(screen.path, filename);
     screen.path = strncat(screen.path, "/", 1);
    
@@ -752,6 +749,8 @@ cb_ok_project(GtkWidget *widget, gpointer data)
 	if (screen.path)
 	    free(screen.path);
 	screen.path = (char *)malloc(strlen(filename) + 2);
+	if (screen.path == NULL)
+	    GERB_FATAL_ERROR("malloc screen.path failed\n");
 	strcpy(screen.path, filename);
 	dirname(screen.path);
 	screen.path = strncat(screen.path, "/", 1);
@@ -772,6 +771,8 @@ cb_ok_project(GtkWidget *widget, gpointer data)
 		screen.project = NULL;
 	    }
 	    screen.project = (char *)malloc(strlen(filename) + 1);
+	    if (screen.project == NULL)
+	    GERB_FATAL_ERROR("malloc screen.project failed\n");
 	    memset((void *)screen.project, 0, strlen(filename) + 1);
 	    strncpy(screen.project, filename, strlen(filename));
             rename_main_window(filename, NULL);
@@ -791,6 +792,8 @@ cb_ok_project(GtkWidget *widget, gpointer data)
 	    screen.project = NULL;
 	}
 	screen.project = (char *)malloc(strlen(filename) + 1);
+	if (screen.project == NULL)
+	    GERB_FATAL_ERROR("malloc screen.proejct failed\n");
 	memset((void *)screen.project, 0, strlen(filename) + 1);
 	strncpy(screen.project, filename, strlen(filename));
 	rename_main_window(filename, NULL);
@@ -803,6 +806,8 @@ cb_ok_project(GtkWidget *widget, gpointer data)
 	
 	if (screen.path) {
 	    project_list = (project_list_t *)malloc(sizeof(project_list_t));
+	    if (project_list == NULL)
+		GERB_FATAL_ERROR("malloc project_list failed\n");
 	    memset(project_list, 0, sizeof(project_list_t));
 	    project_list->next = project_list;
 	    project_list->layerno = -1;
@@ -816,6 +821,8 @@ cb_ok_project(GtkWidget *widget, gpointer data)
 	for (idx = 0; idx < MAX_FILES; idx++) {
 	    if (screen.file[idx] && screen.file[idx]->name) {
 		tmp = (project_list_t *)malloc(sizeof(project_list_t));
+		if (tmp == NULL)
+		    GERB_FATAL_ERROR("malloc tmp failed\n");
 		memset(tmp, 0, sizeof(project_list_t));
 		tmp->next = project_list;
 		tmp->layerno = idx;
@@ -843,6 +850,8 @@ cb_ok_project(GtkWidget *widget, gpointer data)
     if (screen.path)
 	free(screen.path);
     screen.path = (char *)malloc(strlen(filename) + 2);
+    if (screen.path == NULL)
+	GERB_FATAL_ERROR("malloc screen.path failed\n");
     strcpy(screen.path, filename);
     screen.path = strncat(screen.path, "/", 1);
 
@@ -1062,16 +1071,16 @@ autoscale(void)
              */
 	    screen.gerber_bbox.x1 = MIN(screen.gerber_bbox.x1,
 					screen.file[i]->image->info->min_x+
-					screen.file[i]->image->info->offset_a);
+					screen.file[i]->image->info->offset_a_in);
 	    screen.gerber_bbox.y1 = MIN(screen.gerber_bbox.y1,
 					screen.file[i]->image->info->min_y+
-					screen.file[i]->image->info->offset_b);
+					screen.file[i]->image->info->offset_b_in);
 	    screen.gerber_bbox.x2 = MAX(screen.gerber_bbox.x2,
 					screen.file[i]->image->info->max_x+
-					screen.file[i]->image->info->offset_a);
+					screen.file[i]->image->info->offset_a_in);
 	    screen.gerber_bbox.y2 = MAX(screen.gerber_bbox.y2,
 					screen.file[i]->image->info->max_y+
-					screen.file[i]->image->info->offset_b);
+					screen.file[i]->image->info->offset_b_in);
         }
     }
 
@@ -1608,6 +1617,9 @@ open_image(char *filename, int idx, int reload)
     else 
 	parsed_image = parse_gerb(fd);
 
+    if (parsed_image == NULL)
+	return -1;
+
     gerb_fclose(fd);
 
     /*
@@ -1644,16 +1656,18 @@ open_image(char *filename, int idx, int reload)
 	return 0;
     } else {
 	screen.file[idx] = (gerbv_fileinfo_t *)malloc(sizeof(gerbv_fileinfo_t));
+	if (screen.file[idx] == NULL)
+	    GERB_FATAL_ERROR("malloc screen.file[idx] failed\n");
 	memset((void *)screen.file[idx], 0, sizeof(gerbv_fileinfo_t));
 	screen.file[idx]->image = parsed_image;
     }
 
     /*
      * Store filename for eventual reload
-     * XXX Really should check retval from malloc!!! And use strncpy
-     * TOM: not really. filename is not changing between strlen and strcpy
      */
     screen.file[idx]->name = (char *)malloc(strlen(filename) + 1);
+    if (screen.file[idx]->name == NULL)
+	GERB_FATAL_ERROR("malloc screen.file[idx]->name failed\n");
     strcpy(screen.file[idx]->name, filename);
 
     /*
@@ -1665,6 +1679,8 @@ open_image(char *filename, int idx, int reload)
 
 	len = strlen(cptr);
 	screen.file[idx]->basename = (char *)malloc(len + 1);
+	if (screen.file[idx]->basename == NULL)
+	    GERB_FATAL_ERROR("malloc screen.file[idx]->basename failed\n");
 	if (screen.file[idx]->basename) {
 	    strncpy(screen.file[idx]->basename, cptr+1, len);
 	    screen.file[idx]->basename[len] = '\0';
@@ -1778,7 +1794,6 @@ button_press_event (GtkWidget *widget, GdkEventButton *event)
 } /* button_press_event */
 
 
-#ifdef USE_GTK2
 /* Scroll wheel */
 static gint
 scroll_event(GtkWidget *widget, GdkEventScroll *event)
@@ -1808,7 +1823,6 @@ scroll_event(GtkWidget *widget, GdkEventScroll *event)
 
     return TRUE;
 } /* scroll_event */
-#endif
 
 
 static gint
@@ -2443,6 +2457,8 @@ rename_main_window(char *filename, GtkWidget *main_win)
 
     len = strlen(WIN_TITLE) + strlen(VERSION) + 2 + strlen(filename) + 1;
     win_title = (char *)malloc(len);
+    if (win_title == NULL)
+	GERB_FATAL_ERROR("malloc win_title failed\n");
     snprintf(win_title, len, "%s%s: %s", WIN_TITLE, VERSION, filename);
     gtk_window_set_title(GTK_WINDOW(win), win_title);
     free(win_title);
@@ -2641,12 +2657,7 @@ main(int argc, char *argv[])
      */
     main_win = gtk_window_new(GTK_WINDOW_TOPLEVEL);
     rename_main_window("", main_win);
-#ifdef USE_GTK2
     g_signal_connect(GTK_OBJECT(main_win), "delete_event", G_CALLBACK(destroy), NULL);
-#else
-    gtk_signal_connect(GTK_OBJECT(main_win), "delete_event", destroy, NULL);
-    gtk_signal_connect(GTK_OBJECT(main_win), "destroy", destroy, NULL);
-#endif
 
     /* 
      * vbox contains menubar and hbox
@@ -2684,11 +2695,7 @@ main(int argc, char *argv[])
     screen.statusbar.msg = gtk_label_new("");
     gtk_label_set_justify(GTK_LABEL(screen.statusbar.msg), GTK_JUSTIFY_LEFT);
     textStyle = gtk_style_new();
-#ifndef USE_GTK2
-    textStyle->font = gdk_font_load(setup.status_fontname);
-#else
     textStyle->font_desc = pango_font_description_from_string(setup.status_fontname);
-#endif
     gtk_widget_set_style(GTK_WIDGET(screen.statusbar.msg), textStyle);
     screen.statusbar.msgstr[0] = '\0';
     screen.statusbar.coordstr[0] = '\0';
@@ -2714,6 +2721,8 @@ main(int argc, char *argv[])
 		screen.project = NULL;
 	    }
 	    screen.project = (char *)malloc(strlen(project_filename) + 1);
+	    if (screen.project == NULL)
+		GERB_FATAL_ERROR("malloc screen.project failed\n");
 	    memset((void *)screen.project, 0, strlen(project_filename) + 1);
 	    strncpy(screen.project, project_filename, strlen(project_filename));
 	    /*
@@ -2722,6 +2731,8 @@ main(int argc, char *argv[])
 	    if (screen.path)
 		free(screen.path);
 	    screen.path = (char *)malloc(strlen(project_filename) + 2);
+	    if (screen.path == NULL)
+		GERB_FATAL_ERROR("malloc screen.path failed\n");
 	    strcpy(screen.path, project_filename);
 	    dirname(screen.path);
 	    screen.path = strncat(screen.path, "/", 1);
@@ -2761,10 +2772,8 @@ main(int argc, char *argv[])
 		       GTK_SIGNAL_FUNC(key_press_event), NULL);
     gtk_signal_connect_after(GTK_OBJECT(main_win), "key_release_event",
 		       GTK_SIGNAL_FUNC(key_release_event), NULL);
-#ifdef USE_GTK2
     gtk_signal_connect_after(GTK_OBJECT(main_win), "scroll_event",
 		       GTK_SIGNAL_FUNC(scroll_event), NULL);
-#endif
 
     gtk_widget_set_events(screen.drawing_area, GDK_EXPOSURE_MASK
 			  | GDK_LEAVE_NOTIFY_MASK
@@ -2774,9 +2783,7 @@ main(int argc, char *argv[])
 			  | GDK_KEY_RELEASE_MASK
 			  | GDK_POINTER_MOTION_MASK
 			  | GDK_POINTER_MOTION_HINT_MASK
-#ifdef USE_GTK2
 			  | GDK_SCROLL_MASK
-#endif
 			  );
 
     gtk_widget_show_all(main_win);
