@@ -2,11 +2,11 @@
  * gEDA - GNU Electronic Design Automation
  * This file is a part of gerbv.
  *
- *   Copyright (C) 2000-2002 Stefan Petersen (spe@stacken.kth.se)
+ *   Copyright (C) 2000-2006 Stefan Petersen (spe at stacken.kth.se)
  *
- * $Id: log.c,v 1.4 2003/12/14 10:51:36 spetm Exp $
+ * $Id: log.c,v 1.4.8.1 2006/07/26 07:26:13 spetm Exp $
  *
- * Contributed by Dino Ghilardi <dino.ghilardi@ieee.org> 
+ * Contributed by Dino Ghilardi <dino.ghilardi at ieee dot org> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,16 +37,10 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <string.h>
-
-#ifdef USE_GTK2
-/* 
- * XXX GtkText is deprecated in GTK+ 2.0 so this needs a 
- * more permanent solution
- */
-#define GTK_ENABLE_BROKEN 1
-#endif
+#include <errno.h>
 
 #include <gdk/gdkkeysyms.h>
+#include <gtk/gtk.h>
 
 #include "log.h"
 #include "color.h"
@@ -61,8 +55,6 @@ static GtkWidget *create_LogWindow(void);
 static GtkWidget *create_LogFileSelection(void);
 #endif
 
-/* XXX PHONY PROTOTYPE MUST FIX */
-GtkWidget *lookup_widget (GtkWidget * widget, const gchar * widget_name);
 
 /* CallBack Functions prototypes 
  * (cut-n-pasted from Glade-generated file callbacks.h)
@@ -76,13 +68,17 @@ static void logfile_cancel_button_clicked(GtkButton *button, gpointer user_data)
 static void save_log_button_clicked(GtkButton *button, gpointer user_data);
 #endif
 
+/*
+ * Text buffer widget
+ */
+static GtkWidget *textviewLog;
+
 static GtkWidget*
 create_LogWindow (void)
 {
     GtkWidget *LogWindow;
     GtkWidget *vbox1;
     GtkWidget *scrolledwindow1;
-    GtkWidget *logtxt;
     GtkWidget *hbox1;
     GtkWidget *clear_log_button;
 #ifdef SAVE_LOGFILE
@@ -91,83 +87,62 @@ create_LogWindow (void)
     GtkWidget *close_log_button;
     
     LogWindow = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-    gtk_object_set_data (GTK_OBJECT (LogWindow), "LogWindow", LogWindow);
     gtk_window_set_title (GTK_WINDOW (LogWindow), "Log Messages");
-    gtk_window_set_default_size(GTK_WINDOW(LogWindow), 600, 100);
+    gtk_window_set_default_size(GTK_WINDOW(LogWindow), 600, 200);
     
     vbox1 = gtk_vbox_new (FALSE, 0);
-    gtk_widget_ref (vbox1);
-    gtk_object_set_data_full (GTK_OBJECT (LogWindow), "vbox1", vbox1,
-			      (GtkDestroyNotify) gtk_widget_unref);
     gtk_widget_show (vbox1);
     gtk_container_add (GTK_CONTAINER (LogWindow), vbox1);
     
     scrolledwindow1 = gtk_scrolled_window_new (NULL, NULL);
-    gtk_widget_ref (scrolledwindow1);
-    gtk_object_set_data_full (GTK_OBJECT (LogWindow), "scrolledwindow1", 
-			      scrolledwindow1,
-			      (GtkDestroyNotify) gtk_widget_unref);
     gtk_widget_show (scrolledwindow1);
     gtk_box_pack_start (GTK_BOX (vbox1), scrolledwindow1, TRUE, TRUE, 0);
-    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow1), 
-				    GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);
     
-    logtxt = gtk_text_new (NULL, NULL);
-    gtk_widget_ref (logtxt);
-    gtk_object_set_data_full (GTK_OBJECT (LogWindow), "logtxt", logtxt,
-			      (GtkDestroyNotify) gtk_widget_unref);
-    gtk_widget_show (logtxt);
-    gtk_container_add (GTK_CONTAINER (scrolledwindow1), logtxt);
-    
-    hbox1 = gtk_hbox_new (FALSE, 0);
+    textviewLog = gtk_text_view_new();
+    gtk_widget_show(textviewLog);
+    gtk_container_add(GTK_CONTAINER(scrolledwindow1), textviewLog);
+    gtk_text_view_set_editable(GTK_TEXT_VIEW(textviewLog), FALSE);
+    gtk_text_view_set_accepts_tab(GTK_TEXT_VIEW(textviewLog), FALSE);
+    gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(textviewLog), GTK_WRAP_WORD);
+    gtk_text_view_set_cursor_visible(GTK_TEXT_VIEW(textviewLog), FALSE);
+
+    hbox1 = gtk_hbox_new (TRUE, 7);
     gtk_widget_ref (hbox1);
     gtk_object_set_data_full (GTK_OBJECT (LogWindow), "hbox1", hbox1,
                             (GtkDestroyNotify) gtk_widget_unref);
     gtk_widget_show (hbox1);
     gtk_box_pack_start (GTK_BOX (vbox1), hbox1, FALSE, TRUE, 0);
-    gtk_widget_set_usize (hbox1, -2, 24);
+    gtk_widget_set_size_request (hbox1, -1, 28);
 
-    clear_log_button = gtk_button_new_with_label ("Clear log");
-    gtk_widget_ref (clear_log_button);
-    gtk_object_set_data_full (GTK_OBJECT (LogWindow), "clear_log_button", 
-			      clear_log_button,
-			      (GtkDestroyNotify) gtk_widget_unref);
+    clear_log_button = gtk_button_new_with_mnemonic("Clear log");
     gtk_widget_show (clear_log_button);
-    gtk_box_pack_start (GTK_BOX (hbox1), clear_log_button, TRUE, TRUE, 0);
-    gtk_widget_set_usize (clear_log_button, -2, 24);
+    gtk_box_pack_start (GTK_BOX (hbox1), clear_log_button, FALSE, TRUE, 0);
+
 #ifdef SAVE_LOGFILE
-    save_log_button = gtk_button_new_with_label ("Save Log to File");
-    gtk_widget_ref (save_log_button);
-    gtk_object_set_data_full (GTK_OBJECT (LogWindow), "save_log_button", 
-			      save_log_button,
-			      (GtkDestroyNotify) gtk_widget_unref);
-    gtk_widget_show (save_log_button);
-    gtk_box_pack_start (GTK_BOX (hbox1), save_log_button, TRUE, TRUE, 0);
+    save_log_button = gtk_button_new_with_mnemonic("Save to log file");
+    gtk_widget_show(save_log_button);
+    gtk_box_pack_start(GTK_BOX (hbox1), save_log_button, FALSE, TRUE, 0);
+    gtk_widget_set_size_request(save_log_button, -1, 27);
 #endif
-    close_log_button = gtk_button_new_with_label ("Close");
-    gtk_widget_ref (close_log_button);
-    gtk_object_set_data_full (GTK_OBJECT (LogWindow), "close_log_button", 
-			      close_log_button,
-			      (GtkDestroyNotify) gtk_widget_unref);
+
+    close_log_button = gtk_button_new_with_mnemonic("close");
     gtk_widget_show (close_log_button);
-    gtk_box_pack_start (GTK_BOX (hbox1), close_log_button, TRUE, TRUE, 0);
-    gtk_widget_set_usize (close_log_button, -2, 24);
-    
+    gtk_box_pack_start (GTK_BOX (hbox1), close_log_button, FALSE, TRUE, 0);
+    g_signal_connect ((gpointer) clear_log_button, "clicked",
+		      G_CALLBACK (clear_log_button_clicked), NULL);
+
+#ifdef SAVE_LOGFILE
+    g_signal_connect ((gpointer) save_log_button, "clicked",
+		      G_CALLBACK (save_log_button_clicked), NULL);
+#endif
+
+    gtk_signal_connect (GTK_OBJECT (close_log_button), "clicked",
+			GTK_SIGNAL_FUNC (close_log_button_clicked), NULL);
+
     gtk_signal_connect (GTK_OBJECT (LogWindow), "destroy",
 			GTK_SIGNAL_FUNC (LogWindow_destroy),
 			NULL);
-    gtk_signal_connect (GTK_OBJECT (clear_log_button), "clicked",
-			GTK_SIGNAL_FUNC (clear_log_button_clicked),
-			NULL);
-#ifdef SAVE_LOGFILE
-    gtk_signal_connect (GTK_OBJECT (save_log_button), "clicked",
-			GTK_SIGNAL_FUNC (save_log_button_clicked),
-			NULL);
-#endif
-    gtk_signal_connect (GTK_OBJECT (close_log_button), "clicked",
-			GTK_SIGNAL_FUNC (close_log_button_clicked),
-			NULL);
-    
+
     return LogWindow;
 } /* create_LogWindow */
 
@@ -229,16 +204,23 @@ gerbv_gtk_log_handler(const gchar *log_domain,
 		      const gchar *message, 
 		      gpointer user_data)
 {
-    GtkWidget *LogText = NULL;
-    GdkColor textfgcolor;
-    
+    GtkTextBuffer *textbuffer = NULL;
+    GtkTextIter iter;
+    GtkTextTag *tag;
+    GtkTextMark *StartMark = NULL, *StopMark = NULL;
+    GtkTextIter StartIter, StopIter;
     
     /* If the log window does not exist, create it  */
     if(screen.win.log == NULL){
 	screen.win.log = create_LogWindow();
     }
     gtk_widget_show(screen.win.log);
-    LogText =(GtkWidget *)lookup_widget((GtkWidget *)screen.win.log, "logtxt");
+    textbuffer = gtk_text_view_get_buffer((GtkTextView*)textviewLog);
+
+    /* create a mark for the end of the text. */
+    gtk_text_buffer_get_end_iter(textbuffer, &iter);
+
+    gtk_widget_show(screen.win.log);
 
     /*
      * Print text to logfile if we have demanded it.
@@ -246,74 +228,105 @@ gerbv_gtk_log_handler(const gchar *log_domain,
     if(setup.log.to_file) {	/* Append log message to file if required */
 	FILE *fd = NULL;
 	fd = fopen(setup.log.filename, "a");
-	if(fd) {
-	    switch(log_level & G_LOG_LEVEL_MASK) {
-	    case G_LOG_LEVEL_ERROR:
-		fprintf(fd, "ERROR    :");
-		break;
-	    case G_LOG_LEVEL_CRITICAL:
-		fprintf(fd, "CRITICAL :");
-		break;
-	    case G_LOG_LEVEL_WARNING:
-		fprintf(fd, "WARNING  :");
-		break;
-	    case G_LOG_LEVEL_MESSAGE:
-		fprintf(fd, "MESSAGE  :");
-		break;
-	    case G_LOG_LEVEL_INFO:
-		fprintf(fd, "INFO     :");
-		break;
-	    case G_LOG_LEVEL_DEBUG:
-		fprintf(fd, "DEBUG    :");
-		break;
-	    default:
-		fprintf(fd, "Unhandled[%d]:", (int)log_level);
-		break;
-	    }
-	    fprintf(fd, "%s\n", message);
-	    fclose(fd);
-	} else {
-	    /*could not open file... do something else??? 
-	      P.S: do not send a warning using g_warning or whatever 
-	      from here, or a recursion condition
-	      will happen and the program will crash. */
-	    
-	    gdk_color_parse("red", &textfgcolor);
-	    /* allocate text foreground color */
-	    gdk_colormap_alloc_color(gdk_colormap_get_system(), &textfgcolor,
-				     FALSE, TRUE);
-	    gtk_text_insert(GTK_TEXT(LogText), NULL, &textfgcolor, NULL,
-			    "log.c: Could not open log file for writing\n",
-			    -1);
-	    
+	if(fd == NULL) {
+	    fprintf(stderr, "Could not log to file %s:%s\n", 
+		    setup.log.filename, strerror(errno));
+	    exit(0);
 	}
+	switch(log_level & G_LOG_LEVEL_MASK) {
+	case G_LOG_LEVEL_ERROR:
+	    fprintf(fd, "ERROR    :");
+	    break;
+	case G_LOG_LEVEL_CRITICAL:
+	    fprintf(fd, "CRITICAL :");
+	    break;
+	case G_LOG_LEVEL_WARNING:
+	    fprintf(fd, "WARNING  :");
+	    break;
+	case G_LOG_LEVEL_MESSAGE:
+	    fprintf(fd, "MESSAGE  :");
+	    break;
+	case G_LOG_LEVEL_INFO:
+	    fprintf(fd, "INFO     :");
+	    break;
+	case G_LOG_LEVEL_DEBUG:
+	    fprintf(fd, "DEBUG    :");
+	    break;
+	default:
+	    fprintf(fd, "Unhandled[%d]:", (int)log_level);
+	    break;
+	}
+	fprintf(fd, "%s\n", message);
+	fclose(fd);
     }
-    
-    /* now select a different color for a different message. 
+
+    /* Change default color throughout the widget, to set a
+       color different from the default. */
+#if 0
+    gdk_color_parse("green", &color);
+    gtk_widget_modify_text(GTK_WIDGET(textviewLog), GTK_STATE_NORMAL, &color);
+#endif
+
+    /* get the current end position of the text (it will be the
+       start of the new text. */
+    StartMark = gtk_text_buffer_create_mark(textbuffer,
+					    "NewTextStart", &iter, TRUE);
+
+    tag = gtk_text_tag_table_lookup(gtk_text_buffer_get_tag_table(textbuffer),
+                                    "blue_foreground");
+    /* the tag does not exist: create it and let them exist in the tag table.*/
+    if (tag == NULL)    {
+	tag = gtk_text_buffer_create_tag(textbuffer, "black_foreground",
+                                         "foreground", "black", NULL);
+        tag = gtk_text_buffer_create_tag(textbuffer, "blue_foreground",
+                                         "foreground", "blue", NULL);
+        tag = gtk_text_buffer_create_tag(textbuffer, "red_foreground",
+                                         "foreground", "red", NULL);
+        tag = gtk_text_buffer_create_tag(textbuffer, "darkred_foreground",
+                                         "foreground", "darkred", NULL);
+        tag = gtk_text_buffer_create_tag(textbuffer, "darkblue_foreground",
+                                         "foreground", "darkblue", NULL);
+        tag = gtk_text_buffer_create_tag (textbuffer, "darkgreen_foreground",
+                                          "foreground", "darkgreen", NULL);
+        tag = gtk_text_buffer_create_tag (textbuffer,
+                                          "saddlebrown_foreground",
+                                          "foreground", "saddlebrown", NULL);
+    }
+
+    /* 
      * See rgb.txt for the color names definition 
-     * (on my PC it is on /usr/X11R6/lib/X11/rgb.txt) */
-    switch(log_level & G_LOG_LEVEL_MASK) {
+     * (on my PC it is on /usr/X11R6/lib/X11/rgb.txt)
+     */
+    switch (log_level & G_LOG_LEVEL_MASK) {
     case G_LOG_LEVEL_ERROR:
 	/* a message of this kind aborts the application calling abort() */
-	gdk_color_parse("red", &textfgcolor);
+        tag = gtk_text_tag_table_lookup(gtk_text_buffer_get_tag_table(textbuffer),
+                                        "red_foreground");
+
 	break;
     case G_LOG_LEVEL_CRITICAL:
-	gdk_color_parse("red", &textfgcolor);
+        tag = gtk_text_tag_table_lookup(gtk_text_buffer_get_tag_table(textbuffer),
+                                        "red_foreground");
 	break;
     case G_LOG_LEVEL_WARNING:
-	gdk_color_parse("darkred", &textfgcolor);
+        tag = gtk_text_tag_table_lookup(gtk_text_buffer_get_tag_table(textbuffer),
+                                        "darkred_foreground");
 	break;
     case G_LOG_LEVEL_MESSAGE:
-	gdk_color_parse("darkblue", &textfgcolor);
+        tag = gtk_text_tag_table_lookup(gtk_text_buffer_get_tag_table(textbuffer),
+                                        "darkblue_foreground");
 	break;
     case G_LOG_LEVEL_INFO:
-	gdk_color_parse("darkgreen", &textfgcolor);
+        tag = gtk_text_tag_table_lookup(gtk_text_buffer_get_tag_table(textbuffer),
+                                        "drakgreen_foreground");
 	break;
     case G_LOG_LEVEL_DEBUG:
-	gdk_color_parse("SaddleBrown", &textfgcolor);
+	tag = gtk_text_tag_table_lookup(gtk_text_buffer_get_tag_table(textbuffer),
+					"saddlebrown_foreground");
 	break;
     default:
-	gdk_color_parse("black", &textfgcolor);
+        tag = gtk_text_tag_table_lookup (gtk_text_buffer_get_tag_table(textbuffer),
+                                         "black_foreground");
 	break;
     }
 
@@ -322,29 +335,34 @@ gerbv_gtk_log_handler(const gchar *log_domain,
      */
     if (log_level & G_LOG_FLAG_FATAL)
 	fprintf(stderr, "Fatal error : %s\n", message);
-
-    /* allocate text foreground color */
-    gdk_colormap_alloc_color(gdk_colormap_get_system(), &textfgcolor,
-			     FALSE, TRUE);
-
-    /* if needed can be used also a different background color for the text
-     * (see gtk_text_insert documentation)
-     * gtk_text_insert(GtkText *text, GdkFont *font, GdkColor *fore, 
-     * GdkColor *back, const char *chars, gint length);
-     */
-    gtk_text_insert(GTK_TEXT(LogText), NULL, &textfgcolor, NULL, message, -1);
     
-    gdk_colormap_free_colors(gdk_colormap_get_system(), &textfgcolor, 1);
-}
+    gtk_text_buffer_insert(textbuffer, &iter, message, -1);
+    
+    gtk_text_buffer_get_end_iter(textbuffer, &iter);
+    
+    StopMark = gtk_text_buffer_create_mark(textbuffer,
+					   "NewTextStop", &iter, TRUE);
+    
+    gtk_text_buffer_get_iter_at_mark(textbuffer, &StartIter, StartMark);
+    gtk_text_buffer_get_iter_at_mark(textbuffer, &StopIter, StopMark);
+
+    gtk_text_buffer_apply_tag(textbuffer, tag, &StartIter, &StopIter);
+    
+} /* gerbv_gtk_log_handler */
 
 
 static void
 clear_log_button_clicked(GtkButton *button, gpointer user_data)
 {
-    GtkWidget *LogText = NULL;
-    LogText =(GtkWidget *)lookup_widget((GtkWidget *)screen.win.log, "logtxt");
-    gtk_text_backward_delete(GTK_TEXT(LogText),
-			     gtk_text_get_length(GTK_TEXT(LogText)));
+    GtkTextBuffer *textbuffer = NULL;
+    GtkTextIter iterstart, iterend;
+    textbuffer = gtk_text_view_get_buffer((GtkTextView *)textviewLog);
+    
+    gtk_text_buffer_get_start_iter(textbuffer, &iterend);
+    gtk_text_buffer_get_end_iter(textbuffer, &iterstart);
+    
+    gtk_text_buffer_delete(textbuffer, &iterstart, &iterend);
+
 } /* clear_log_button_clicked */
 
 
